@@ -1,11 +1,11 @@
-## deriv <- function(expr, ...)UseMethod('deriv')
+deriv <- function(expr, ...) UseMethod('deriv')
 
-deriv.fd <- function(expr, Lfdobj=int2Lfd(1), returnMatrix=FALSE, ...)
+deriv.fd <- function(expr, Lfdobj=int2Lfd(1), ...)
 {
   #  Applies linear differential operator LFD to functional data object FD
   #    and returns the result as functional data object DERIVFD.
 
-  #  Last modified 8 May 2012 by Jim Ramsay
+  #  Last modified 6 January 2020 by Jim Ramsay
 
   fdobj <- expr
   if (!inherits(fdobj, "fd")) stop(
@@ -18,9 +18,9 @@ deriv.fd <- function(expr, Lfdobj=int2Lfd(1), returnMatrix=FALSE, ...)
   rangeval <- basisobj$rangeval
 
   evalarg  <- seq(rangeval[1], rangeval[2], len=10*nbasis+1)
-  Lfdmat   <- eval.fd(evalarg, fdobj, Lfdobj, returnMatrix)
+  Lfdmat   <- eval.fd(evalarg, fdobj, Lfdobj)
 
-  Lfdcoef  <- project.basis(Lfdmat, evalarg, basisobj, returnMatrix)
+  Lfdcoef  <- project.basis(Lfdmat, evalarg, basisobj)
 
   Dfdnames <- fdobj$fdnames
   Dfdnames[[3]] <- paste("D",Dfdnames[[3]])
