@@ -1,6 +1,5 @@
 landmarkreg <- function(fdobj, ximarks, x0marks=xmeanmarks,
-                        WfdPar=NULL, monwrd=FALSE, ylambda=1e-10,
-                        returnMatrix=FALSE)
+                        WfdPar=NULL, monwrd=FALSE, ylambda=1e-10)
 {
 #  Arguments:
 #  FDOBJ   ... functional data object for curves to be registered
@@ -8,10 +7,7 @@ landmarkreg <- function(fdobj, ximarks, x0marks=xmeanmarks,
 #                 each observed curve
 #  XOMARKS ... vector of length NL of times of interior landmarks for
 #                 target curve
-#  WFDPAR  ... a functional parameter object defining a warping function.  
-#                 If NULL, registration is done using linear interpolation
-#                 of lamdmark times in XIMARKS plotted against corresponding 
-#                 target times in X0MARKS.
+#  WFDPAR  ... a functional parameter object defining a warping function
 #  MONWRD  ... If TRUE, warping functions are estimated by monotone smoothing,
 #                 otherwise by regular smoothing.  The latter is faster, but
 #                 not guaranteed to produce a strictly monotone warping
@@ -28,11 +24,8 @@ landmarkreg <- function(fdobj, ximarks, x0marks=xmeanmarks,
 #  WARPFD  ... a functional data object for the warping functions
 #  WFD     ... a functional data object for the W functions defining the
 #              warping functions
-#  RETURNMATRIX ... If False, a matrix in sparse storage model can be returned
-#               from a call to function BsplineS.  See this function for
-#               enabling this option.
 
- #  Last modified 14 November 2012 by Jim Ramsay
+ #  Last modified 6 January 2020 by Jim Ramsay
 
   #  check FDOBJ
 
@@ -51,10 +44,11 @@ landmarkreg <- function(fdobj, ximarks, x0marks=xmeanmarks,
       nvar <- 1
   }
 
-  basisobj  <- fdobj$basis
-  nbasis    <- basisobj$nbasis
-  rangeval  <- basisobj$rangeval
-  fdParobj  <- fdPar(basisobj, 2, ylambda)
+  basisobj <- fdobj$basis
+  type     <- basisobj$type
+  nbasis   <- basisobj$nbasis
+  rangeval <- basisobj$rangeval
+  fdParobj <- fdPar(basisobj, 2, ylambda)
 
   #  check landmarks
 
@@ -105,7 +99,7 @@ landmarkreg <- function(fdobj, ximarks, x0marks=xmeanmarks,
   n   <- min(c(101,10*nbasis))
   x   <- seq(rangeval[1],rangeval[2],length=n)
 
-  y       <- eval.fd(x, fdobj, returnMatrix=returnMatrix)
+  y       <- eval.fd(x, fdobj)
   yregmat <- y
   hfunmat <- matrix(0,n,ncurve)
   wlambda <- max(wlambda,1e-10)
@@ -129,9 +123,10 @@ landmarkreg <- function(fdobj, ximarks, x0marks=xmeanmarks,
     #  smooth relation between this curve"s values and target"s values
     if (monwrd) {
        #  use monotone smoother
-       Wfds      <- smooth.morph(xval, yval, WfdPar)
-       Wfd       <- Wfds$Wfdobj
-       h         <- monfn(x, Wfd, returnMatrix=returnMatrix)
+#       Wfd       <- smooth.morph(xval, yval, WfdPar)$Wfdobj
+       Wfds       <- smooth.morph(xval, yval, WfdPar)
+       Wfd <- Wfds$Wfdobj
+       h         <- monfn(x, Wfd)
        b         <- (rangeval[2]-rangeval[1])/(h[n]-h[1])
        a         <- rangeval[1] - b*h[1]
        h         <- a + b*h
@@ -142,7 +137,7 @@ landmarkreg <- function(fdobj, ximarks, x0marks=xmeanmarks,
        #  use unconstrained smoother
        warpfd <- smooth.basis(xval, yval, WfdPar, wval)$fd
        #  set up warping function by evaluating at sampling values
-       h         <- as.vector(eval.fd(x, warpfd, returnMatrix=returnMatrix))
+       h         <- as.vector(eval.fd(x, warpfd))
        b         <- (rangeval[2]-rangeval[1])/(h[n]-h[1])
        a         <- rangeval[1] - b*h[1]
        h         <- a + b*h
@@ -164,14 +159,14 @@ landmarkreg <- function(fdobj, ximarks, x0marks=xmeanmarks,
        Wfdinv       <- fd(-wcoef,wbasis)
        WfdParinv    <- fdPar(Wfdinv, wLfd, wlambda)
        Wfdinv       <- smooth.morph(h, x, WfdParinv)$Wfdobj
-       hinv         <- monfn(x, Wfdinv, returnMatrix=returnMatrix)
+       hinv         <- monfn(x, Wfdinv)
        b            <- (rangeval[2]-rangeval[1])/(hinv[n]-hinv[1])
        a            <- rangeval[1] - b*hinv[1]
        hinv         <- a + b*hinv
        hinv[c(1,n)] <- rangeval
    } else {
        hinvfd       <- smooth.basis(h, x, WfdPar)$fd
-       hinv         <- as.vector(eval.fd(x, hinvfd, returnMatrix=returnMatrix))
+       hinv         <- as.vector(eval.fd(x, hinvfd))
        b            <- (rangeval[2]-rangeval[1])/(hinv[n]-hinv[1])
        a            <- rangeval[1] - b*hinv[1]
        hinv         <- a + b*hinv
@@ -186,15 +181,14 @@ landmarkreg <- function(fdobj, ximarks, x0marks=xmeanmarks,
     if (length(dim(coef)) == 2) {
         #  single variable case
         yregfd <- smooth.basis(hinv, y[,icurve], fdParobj)$fd
-        yregmat[,icurve] <- eval.fd(x, yregfd, 0, returnMatrix=returnMatrix)
+        yregmat[,icurve] <- eval.fd(x, yregfd, 0)
     }
     if (length(dim(coef)) == 3) {
         #  multiple variable case
         for (ivar in 1:nvar) {
             # evaluate curve as a function of h at sampling points
             yregfd <- smooth.basis(hinv, y[,icurve,ivar], fdParobj)$fd
-            yregmat[,icurve,ivar] <- eval.fd(x, yregfd,
-                                             returnMatrix=returnMatrix)
+            yregmat[,icurve,ivar] <- eval.fd(x, yregfd)
         }
      }
   }
